% Convert all .mat files in the "mat" folder
% into GDSII files in the "gds" folder
%
% @author Nicolas Lebbe
% @date 22/04/2020

% All the .mat files to convert
mats = dir('mat/*.mat');
nb = length(mats);

for i = 1:nb

  [~, filename] = fileparts(mats(i).name);
  matFile = ['mat/',filename,'.mat'];
  gdsFile = ['gds/',filename,'.gds'];

  fprintf('Convert %03d/%03d: %s\n', i, nb, filename);

  % Load the data of the .mat file
  mat = load(matFile);
  pattern = mat.pattern;

  width = mat.period(1);
  height = mat.period(2);

  % Export in GDSII
  toGDS( ...
    pattern, ...
    gdsFile, ...
    'width', width, ...
    'height', height, ...
    'levelset', 0.5 ...
  );

end
